from .client import Client, SEND_METHOD
from .server import Server, outstr

SEND_METHOD = SEND_METHOD
Server = Server
Client = Client
outstr = outstr